@@ -26,6 +26,7 @@
 #include <errno.h>
 
 #include <gmodule.h>
+#include <glib/gstdio.h>
 
 #include "pango-enum-types.h"
 #include "pango-modules.h"
@@ -168,7 +169,7 @@ pango_module_load (GTypeModule *module)
 
   if (pango_module->path)
     {
-      pango_module->library = g_module_open (pango_module->path, 0);
+      pango_module->library = g_module_open (pango_module->path, G_MODULE_BIND_LAZY);
       if (!pango_module->library)
 	{
 	  g_warning (g_module_error());
@@ -494,7 +495,7 @@ read_modules (void)
 
   while (n-- > 0)
     {
-      module_file = fopen (files[n], "r");
+      module_file = g_fopen (files[n], "r");
       if (module_file)
 	{
 	  process_module_file(module_file);
@@ -652,7 +653,7 @@ pango_map_get_engine (PangoMap   *map,
     return NULL;
 }
 
-void
+static void
 append_engines (GSList **engine_list,
 		GSList  *pair_list)
 {
