@@ -84,14 +84,16 @@ struct _PangoScriptIter
 
 /**
  * pango_script_for_unichar:
- * @ch: a unicode characters
+ * @ch: a Unicode character
  * 
  * Looks up the #PangoScript for a particular character (as defined by
- * Unicode Technical report #24). No check is made for @ch being
- * valid unicode character; if you pass in invalid character, the
+ * Unicode Standard Annex #24). No check is made for @ch being a
+ * valid Unicode character; if you pass in invalid character, the
  * result is undefined.
  * 
  * Return value: the #PangoScript for the character.
+ *
+ * Since: 1.4
  **/
 PangoScript
 pango_script_for_unichar (gunichar ch)
@@ -118,16 +120,19 @@ pango_script_for_unichar (gunichar ch)
 /**
  * pango_script_iter_new:
  * @text: a UTF-8 string
- * @length: length of @text, or -1 if @text is NUL-terminated.
+ * @length: length of @text, or -1 if @text is nul-terminated.
  * 
  * Create a new #PangoScriptIter, used to break a string of
  * Unicode into runs by text. No copy is made of @text, so
  * the caller needs to make sure it remains valid until
  * the iterator is freed with pango_script_iter_free ().x
  * 
- * Return value: the newly created script iterator, initialized
- *  to point at the first range in the text. If the string is
+ * Return value: the new script iterator, initialized
+ *  to point at the first range in the text, which should be
+ *  freed with pango_script_iter_free(). If the string is
  *  empty, it will point at an empty range.
+ *
+ * Since: 1.4
  **/
 PangoScriptIter *
 pango_script_iter_new (const char *text,
@@ -157,6 +162,8 @@ pango_script_iter_new (const char *text,
  * @iter: a #PangoScriptIter
  * 
  * Frees a #PangoScriptIter created with pango_script_iter_new().
+ *
+ * Since: 1.4
  **/
 void
 pango_script_iter_free (PangoScriptIter *iter)
@@ -174,6 +181,8 @@ pango_script_iter_free (PangoScriptIter *iter)
  * Gets information about the range to which @iter currently points.
  * The range is the set of locations p where *start <= p < *end.
  * (That is, it doesn't include the character stored at *end)
+ *
+ * Since: 1.4
  **/
 void
 pango_script_iter_get_range (PangoScriptIter      *iter,
@@ -247,6 +256,8 @@ get_pair_index (gunichar ch)
  * is returned.
  * 
  * Return value: %TRUE if the iter was succesfully advanced.
+ *
+ * Since: 1.4
  **/
 gboolean
 pango_script_iter_next (PangoScriptIter *iter)
@@ -535,6 +546,18 @@ pango_script_get_sample_language (PangoScript script)
     "",    /* PANGO_SCRIPT_LINEAR_B */
     "",    /* PANGO_SCRIPT_TAI_LE */
     "uga", /* PANGO_SCRIPT_UGARITIC */
+    
+    "",    /* PANGO_SCRIPT_NEW_TAI_LUE */
+    "bug", /* PANGO_SCRIPT_BUGINESE */
+    /* The original script for Old Church Slavonic (chu), later
+     * written with Cyrillic */
+    "",    /* PANGO_SCRIPT_GLAGOLITIC */
+    /* Used for for Berber (ber), but Arabic script is more common */
+    "",    /* PANGO_SCRIPT_TIFINAGH */
+    /* Syloti Nagri is used for Sylheti, no ISO 639 code */
+    "",    /* PANGO_SCRIPT_SYLOTI_NAGRI */
+    "peo", /* PANGO_SCRIPT_OLD_PERSIAN */
+    "",    /*  PANGO_SCRIPT_KHAROSHTHI */
   };
   const char *sample_language;
   
